pilot.api.compute.api.Callback

Package pilot :: Package api :: Package compute :: Module api :: Class Callback |

# Class Callback

source code

Callback class.

Specifies the structure for callback classes.

Callbacks can be set for WorkUnits on the state or state_detail members.

Instance Methods
cb(self, wu, member, value) This is the method that needs to be implemented by the application | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### cb(self, wu, member, value) | source code
This is the method that needs to be implemented by the application Keyword arguments: wu -- The WU that is calling back. member -- The member that triggered the callback. value -- The new (detailed) state. Return: Keep -- Keep or remove the callback